@@ -1,8 +1,7 @@
 from ipaddress import IPV4LENGTH, IPV6LENGTH, IPv4Network, ip_address, ip_network
 from typing import Dict, List, Optional, Tuple
 
-from text_unidecode import unidecode
-
+from ...decode import unidecode
 from ...utils.decorators import lowercase, slugify, slugify_unicode
 from ...utils.distribution import choices_distribution
 from .. import BaseProvider, ElementsType
@@ -155,7 +154,7 @@ class Provider(BaseProvider):
         "{{url}}{{uri_path}}/{{uri_page}}{{uri_extension}}",
     )
     image_placeholder_services: ElementsType = (
-        "https://www.lorempixel.com/{width}/{height}",
+        "https://picsum.photos/{width}/{height}",
         "https://dummyimage.com/{width}x{height}",
         "https://placekitten.com/{width}/{height}",
         "https://placeimg.com/{width}/{height}/any",
@@ -320,10 +319,10 @@ class Provider(BaseProvider):
     def url(self, schemes: Optional[List[str]] = None) -> str:
         """
         :param schemes: a list of strings to use as schemes, one will chosen randomly.
-        If None, it will generate http and https urls.
-        Passing an empty list will result in schemeless url generation like "://domain.com".
+            If None, it will generate http and https urls.
+            Passing an empty list will result in schemeless url generation like "://domain.com".
+        :return: a random url string.
 
-        :returns: a random url string.
         """
         if schemes is None:
             schemes = ["http", "https"]
@@ -585,7 +584,7 @@ class Provider(BaseProvider):
 
     def ipv6(self, network: bool = False) -> str:
         """Produce a random IPv6 address or network with a valid CIDR"""
-        address = str(ip_address(self.generator.random.randint(2 ** IPV4LENGTH, (2 ** IPV6LENGTH) - 1)))
+        address = str(ip_address(self.generator.random.randint(2**IPV4LENGTH, (2**IPV6LENGTH) - 1)))
         if network:
             address += "/" + str(self.generator.random.randint(0, IPV6LENGTH))
             address = str(ip_network(address, strict=False))
@@ -637,14 +636,27 @@ class Provider(BaseProvider):
             value = self.generator.text(20)
         return value
 
-    def image_url(self, width: Optional[int] = None, height: Optional[int] = None) -> str:
+    def image_url(
+        self,
+        width: Optional[int] = None,
+        height: Optional[int] = None,
+        placeholder_url: Optional[str] = None,
+    ) -> str:
         """
         Returns URL to placeholder image
         Example: http://placehold.it/640x480
+
+        :param width: Optional image width
+        :param height: Optional image height
+        :param placeholder_url: Optional template string of image URLs from custom
+            placeholder service. String must contain ``{width}`` and ``{height}``
+            placeholders, eg: ``https:/example.com/{width}/{height}``.
+        :rtype: str
         """
         width_ = width or self.random_int(max=1024)
         height_ = height or self.random_int(max=1024)
-        placeholder_url: str = self.random_element(self.image_placeholder_services)
+        if placeholder_url is None:
+            placeholder_url = self.random_element(self.image_placeholder_services)
         return placeholder_url.format(width=width_, height=height_)
 
     def iana_id(self) -> str:
