@@ -4,11 +4,12 @@ import sys
 import warnings
 
 from decimal import Decimal
-from typing import Any, Dict, Iterable, Iterator, List, Optional, Tuple, Union, no_type_check
+from typing import Any, Dict, Iterable, Iterator, List, Optional, Set, Tuple, Type, Union, no_type_check
 
 from .. import BaseProvider, ElementsType
 
-ValueTypes = Optional[Union[List[str], Tuple[str, ...]]]
+TypesNames = List[str]
+TypesSpec = Union[List[Type], Tuple[Type, ...]]
 
 
 class Provider(BaseProvider):
@@ -26,27 +27,34 @@ class Provider(BaseProvider):
         "email",
     )
 
-    def _check_signature(self, value_types: ValueTypes, allowed_types: Tuple[str]) -> Tuple[str, ...]:
+    def _check_signature(self, value_types: Optional[TypesSpec], allowed_types: Optional[TypesSpec]) -> TypesSpec:
         if value_types is not None and not isinstance(value_types, (list, tuple)):
-            value_types = [value_types]
+            value_types = (value_types,)
             warnings.warn(
-                "Passing value types as positional arguments is going to be "
+                "Passing `value_types` as positional arguments is going to be "
+                "deprecated.  Pass them as a list or tuple instead.",
+                PendingDeprecationWarning,
+            )
+        if allowed_types is not None and not isinstance(allowed_types, (list, tuple)):
+            allowed_types = (allowed_types,)
+            warnings.warn(
+                "Passing `allowed_types` as positional arguments is going to be "
                 "deprecated.  Pass them as a list or tuple instead.",
                 PendingDeprecationWarning,
             )
         if value_types is None:
             value_types = ()
-        return tuple(value_types) + allowed_types
+        if allowed_types is None:
+            allowed_types = ()
+        return tuple(value_types) + tuple(allowed_types)
 
-    def pybool(self):
+    def pybool(self) -> bool:
         return self.random_int(0, 1) == 1
 
-    def pystr(self, min_chars=None, max_chars=20):
+    def pystr(self, min_chars: Optional[int] = None, max_chars: int = 20) -> str:
         """
         Generates a random string of upper and lowercase letters.
-        :type min_chars: int
-        :type max_chars: int
-        :return: String. Random of random length between min and max characters.
+        :return: Random of random length between min and max characters.
         """
         if min_chars is None:
             return "".join(self.random_letters(length=max_chars))
@@ -58,10 +66,21 @@ class Provider(BaseProvider):
                 ),
             )
 
-    def pystr_format(self, string_format="?#-###{{random_int}}{{random_letter}}", letters=string.ascii_letters):
+    def pystr_format(
+        self,
+        string_format: str = "?#-###{{random_int}}{{random_letter}}",
+        letters: str = string.ascii_letters,
+    ) -> str:
         return self.bothify(self.generator.parse(string_format), letters=letters)
 
-    def pyfloat(self, left_digits=None, right_digits=None, positive=False, min_value=None, max_value=None):
+    def pyfloat(
+        self,
+        left_digits=None,
+        right_digits=None,
+        positive=False,
+        min_value=None,
+        max_value=None,
+    ):
         if left_digits is not None and left_digits < 0:
             raise ValueError("A float number cannot have less than 0 digits in its " "integer part")
         if right_digits is not None and right_digits < 0:
@@ -103,9 +122,9 @@ class Provider(BaseProvider):
             # Make sure left_digits still respected
             if left_digits is not None:
                 if max_value is None:
-                    max_value = 10 ** left_digits  # minus smallest representable, adjusted later
+                    max_value = 10**left_digits  # minus smallest representable, adjusted later
                 if min_value is None:
-                    min_value = -(10 ** left_digits)  # plus smallest representable, adjusted later
+                    min_value = -(10**left_digits)  # plus smallest representable, adjusted later
 
             if max_value is not None and max_value < 0:
                 max_value += 1  # as the random_int will be generated up to max_value - 1
@@ -128,11 +147,11 @@ class Provider(BaseProvider):
                 result += sys.float_info.epsilon
 
         if right_digits:
-            result = min(result, 10 ** left_digits - float(f'0.{"0" * (right_digits - 1)}1'))
-            result = max(result, -(10 ** left_digits + float(f'0.{"0" * (right_digits - 1)}1')))
+            result = min(result, 10**left_digits - float(f'0.{"0" * (right_digits - 1)}1'))
+            result = max(result, -(10**left_digits + float(f'0.{"0" * (right_digits - 1)}1')))
         else:
-            result = min(result, 10 ** left_digits - 1)
-            result = max(result, -(10 ** left_digits + 1))
+            result = min(result, 10**left_digits - 1)
+            result = max(result, -(10**left_digits + 1))
 
         return result
 
@@ -152,10 +171,17 @@ class Provider(BaseProvider):
         else:
             return self.random_int(min_value, max_value - 1)
 
-    def pyint(self, min_value=0, max_value=9999, step=1):
+    def pyint(self, min_value: int = 0, max_value: int = 9999, step: int = 1) -> int:
         return self.generator.random_int(min_value, max_value, step=step)
 
-    def pydecimal(self, left_digits=None, right_digits=None, positive=False, min_value=None, max_value=None):
+    def pydecimal(
+        self,
+        left_digits=None,
+        right_digits=None,
+        positive=False,
+        min_value=None,
+        max_value=None,
+    ):
         if left_digits is not None and left_digits < 0:
             raise ValueError("A decimal number cannot have less than 0 digits in its " "integer part")
         if right_digits is not None and right_digits < 0:
@@ -177,7 +203,8 @@ class Provider(BaseProvider):
         max_random_digits = 100
         # Because if min_value is bigger than 10**100
         max_digits_from_value = max(
-            math.ceil(math.log10(abs(min_value or 1))), math.ceil(math.log10(abs(max_value or 1)))
+            math.ceil(math.log10(abs(min_value or 1))),
+            math.ceil(math.log10(abs(max_value or 1))),
         )
         max_left_random_digits = max(max_random_digits, max_digits_from_value + 10)
 
@@ -193,14 +220,16 @@ class Provider(BaseProvider):
                 left_number = str(self.random_int(max(min_value or 0, 0), max_value))
             else:
                 min_left_digits = math.ceil(math.log10(max(min_value or 1, 1)))
-                left_digits = left_digits or self.random_int(min_left_digits, max_left_random_digits)
+                if left_digits is None:
+                    left_digits = self.random_int(min_left_digits, max_left_random_digits)
                 left_number = "".join([str(self.random_digit()) for i in range(0, left_digits)]) or "0"
         else:
             if min_value is not None:
                 left_number = str(self.random_int(max(max_value or 0, 0), abs(min_value)))
             else:
                 min_left_digits = math.ceil(math.log10(abs(min(max_value or 1, 1))))
-                left_digits = left_digits or self.random_int(min_left_digits, max_left_random_digits)
+                if left_digits is None:
+                    left_digits = self.random_int(min_left_digits, max_left_random_digits)
                 left_number = "".join([str(self.random_digit()) for i in range(0, left_digits)]) or "0"
 
         if right_digits is None:
@@ -219,26 +248,68 @@ class Provider(BaseProvider):
 
         return result
 
-    def pytuple(self, nb_elements=10, variable_nb_elements=True, value_types=None, *allowed_types):
-        return tuple(self._pyiterable(nb_elements, variable_nb_elements, value_types, *allowed_types))
+    def pytuple(
+        self,
+        nb_elements: int = 10,
+        variable_nb_elements: bool = True,
+        value_types: Optional[TypesSpec] = None,
+        allowed_types: Optional[TypesSpec] = None,
+    ) -> Tuple[Any, ...]:
+        return tuple(
+            self._pyiterable(
+                nb_elements=nb_elements,
+                variable_nb_elements=variable_nb_elements,
+                value_types=value_types,
+                allowed_types=allowed_types,
+            )
+        )
 
-    def pyset(self, nb_elements=10, variable_nb_elements=True, value_types=None, *allowed_types):
-        return set(self._pyiterable(nb_elements, variable_nb_elements, value_types, *allowed_types))
+    def pyset(
+        self,
+        nb_elements: int = 10,
+        variable_nb_elements: bool = True,
+        value_types: Optional[TypesSpec] = None,
+        allowed_types: Optional[TypesSpec] = None,
+    ) -> Set[Any]:
+        return set(
+            self._pyiterable(
+                nb_elements=nb_elements,
+                variable_nb_elements=variable_nb_elements,
+                value_types=value_types,
+                allowed_types=allowed_types,
+            )
+        )
 
-    def pylist(self, nb_elements=10, variable_nb_elements=True, value_types=None, *allowed_types):
-        return list(self._pyiterable(nb_elements, variable_nb_elements, value_types, *allowed_types))
+    def pylist(
+        self,
+        nb_elements: int = 10,
+        variable_nb_elements: bool = True,
+        value_types: Optional[TypesSpec] = None,
+        allowed_types: Optional[TypesSpec] = None,
+    ) -> List[Any]:
+        return list(
+            self._pyiterable(
+                nb_elements=nb_elements,
+                variable_nb_elements=variable_nb_elements,
+                value_types=value_types,
+                allowed_types=allowed_types,
+            )
+        )
 
     @no_type_check
     def pyiterable(
         self,
         nb_elements: int = 10,
         variable_nb_elements: bool = True,
-        value_types: ValueTypes = None,
-        *allowed_types: str,
+        value_types: Optional[TypesSpec] = None,
+        allowed_types: Optional[TypesSpec] = None,
     ) -> Iterable[Any]:
-        value_types = self._check_signature(value_types, allowed_types)
+        value_types: TypesSpec = self._check_signature(value_types, allowed_types)
         return self.random_element([self.pylist, self.pytuple, self.pyset])(
-            nb_elements, variable_nb_elements, value_types, *allowed_types
+            nb_elements=nb_elements,
+            variable_nb_elements=variable_nb_elements,
+            value_types=value_types,
+            allowed_types=allowed_types,
         )
 
     def _random_type(self, type_list: List[str]) -> str:
@@ -254,13 +325,13 @@ class Provider(BaseProvider):
         self,
         nb_elements: int = 10,
         variable_nb_elements: bool = True,
-        value_types: ValueTypes = None,
-        *allowed_types: str,
+        value_types: Optional[TypesSpec] = None,
+        allowed_types: Optional[TypesSpec] = None,
     ) -> Iterator:
 
-        value_types = self._check_signature(value_types, allowed_types)  # type: ignore
+        value_types: TypesSpec = self._check_signature(value_types, allowed_types)
 
-        value_types = [
+        value_types: TypesNames = [
             t if isinstance(t, str) else getattr(t, "__name__", type(t).__name__).lower()
             for t in value_types
             # avoid recursion
@@ -275,7 +346,13 @@ class Provider(BaseProvider):
         for _ in range(nb_elements):
             yield self._random_type(value_types)
 
-    def pydict(self, nb_elements=10, variable_nb_elements=True, value_types=None, *allowed_types):
+    def pydict(
+        self,
+        nb_elements: int = 10,
+        variable_nb_elements: bool = True,
+        value_types: Optional[TypesSpec] = None,
+        allowed_types: Optional[TypesSpec] = None,
+    ) -> Dict[Any, Any]:
         """
         Returns a dictionary.
 
@@ -289,14 +366,21 @@ class Provider(BaseProvider):
         return dict(
             zip(
                 self.generator.words(nb_elements, unique=True),
-                self._pyiterable(nb_elements, False, value_types, *allowed_types),
+                self._pyiterable(
+                    nb_elements=nb_elements,
+                    variable_nb_elements=False,
+                    value_types=value_types,
+                    allowed_types=allowed_types,
+                ),
             )
         )
 
-    def pystruct(self, count: int = 10, value_types: ValueTypes = None, *allowed_types: str) -> Tuple[List, Dict, Dict]:
-        value_types = self._check_signature(value_types, allowed_types)  # type: ignore
+    def pystruct(
+        self, count: int = 10, value_types: Optional[TypesSpec] = None, allowed_types: Optional[TypesSpec] = None
+    ) -> Tuple[List, Dict, Dict]:
+        value_types: TypesSpec = self._check_signature(value_types, allowed_types)
 
-        value_types = [
+        value_types: TypesNames = [
             t if isinstance(t, str) else getattr(t, "__name__", type(t).__name__).lower()
             for t in value_types
             # avoid recursion
@@ -313,12 +397,21 @@ class Provider(BaseProvider):
             types.append(self._random_type(value_types))
             nd[self.generator.word()] = {
                 i: self._random_type(value_types),
-                i + 1: [self._random_type(value_types), self._random_type(value_types), self._random_type(value_types)],
+                i
+                + 1: [
+                    self._random_type(value_types),
+                    self._random_type(value_types),
+                    self._random_type(value_types),
+                ],
                 i
                 + 2: {
                     i: self._random_type(value_types),
                     i + 1: self._random_type(value_types),
-                    i + 2: [self._random_type(value_types), self._random_type(value_types)],
+                    i
+                    + 2: [
+                        self._random_type(value_types),
+                        self._random_type(value_types),
+                    ],
                 },
             }
         return types, d, nd
